# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CourseConstant:
    RESULT = 'result'
    RESULT_DESC = 'resultDesc'
    RESULT_CODE = 'resultCode'

    COURSE_STATUS_RESPONSE = 'edukit_sdk.edukit.course.resp.' \
                             'course_status_response.CourseStatusResponse'
    CREATE_COURSE_RESULT = 'edukit_sdk.edukit.course.impl.' \
                           'create_course_result.CreateCourseResult'

    COURSE_AUDIO_FILE = 'COURSE_AUDIO_FILE'
    COURSE_VIDEO_FILE = 'COURSE_VIDEO_FILE'

    MATERIAL_Id = 'materialId'
    PATH = 'path'

    COURSE_PACKAGE_HORIZONTAL_COVER = 'COURSE_PACKAGE_HORIZONTAL_COVER'
    COURSE_PORTRAIT_COVER = 'COURSE_PORTRAIT_COVER'
    COURSE_PACKAGE_INTRODUCTION = 'COURSE_PACKAGE_INTRODUCTION'
    PROMOTIONAL_VIDEO_POSTER = 'PROMOTIONAL_VIDEO_POSTER'
    COURSE_INTRODUCTION_VIDEO = 'COURSE_INTRODUCTION_VIDEO'
    CANCEL_COMMIT = 'CANCEL_COMMIT'
    COURSE_Id = 'courseId'
    COURSE_EDIT_ID = 'courseEditId'
