# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class LessonConstant:
    CreateLessonResult = 'edukit_sdk.edukit.lesson.impl.' \
                         'create_lesson_result.CreateLessonResult'
    RESPONSE = 'edukit_sdk.edukit.common.model.response.Response'
    UPDATE_LESSON_RESULT = 'edukit_sdk.edukit.lesson.impl.' \
                           'update_lesson_result.UpdateLessonResult'
