# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CatalogueConstant:
    CREATE_CATALOGUE_RESPONSE = 'edukit_sdk.edukit.catalogue' \
                                '.resp.create_catalogue_response' \
                                '.CreateCatalogueResponse'
    UPDATE_CATALOGUE_RESPONSE = 'edukit_sdk.edukit.catalogue.resp' \
                                '.update_catalogue_response' \
                                '.UpdateCatalogueResponse'
    RESULT = 'result'
    RESULT_CODE = 'resultCode'
    RESULT_DESC = 'resultDesc'
