#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class ClientConstant:
    FILE_SIZE = 'fileSize'
    FILE_SHA256 = 'fileSha256'
    RESOURCE_TYPE = 'resourseType'
    FILE_NAME = 'fileName'
    FILE = 'file'
    FILE_TYPE = 'fileType'
    PUBLIC_FILE = 'publicFile'
    PART_MAXSIZE = 'PART_MAXSIZE'
    TMP_UPLOAD_URL = 'tmpUploadUrl'
    UPLOAD_HEADERS = 'uploadHeaders'
    UPLOAD_METHOD = 'uploadMethod'
    FILE_ID = 'fileId'
    FILE_PARTS = 'fileParts'
    PART_OBJECT_ID = 'partObjectId'
    MATERIAL_URL = 'materialUrl'
    GOOGLE_GENERATION = 'googleGeneration'
    X_GOOGLE_GENERATION = 'X-Google-Generation'
    MULTI_PART_FLAG = 'multiPartFlag'
    UTF_8 = 'utf-8'
    RB = "rb"
    MAX_PAER_SIZE = 'maxPartSize'
    _HEADERS = '_headers'
    E_TAG = 'ETag'
    SERVER_DOMAIN = 'SERVER_DOMAIN'
    SDK_NAME = 'SDK_NAME'
    SDK_VERSION = 'SDK_VERSION'
    REQUESTING = 'Requesting'
    TUTOR_PORTRAIT = 'TUTOR_PORTRAIT'
    ERROR_MESSAGE = 'error_message'
